@@ -320,10 +320,10 @@ class EidCache(BaseModel):
 
 
 class JobSummariesCache(BaseModel):
-    jobs: JobSummaries
+    job_summaries: JobSummaries
     created_at: Optional[str]
 
 
-class TablesCache(BaseModel):
-    tables: TableDetails
-    created_at: Optional[str]
+class TableSummariesCache(BaseModel):
+    table_summaries: TableSummaries
+    created_at: Optional[str]
\ No newline at end of file
